######
Log in
######

When you visit a brand new site for the first time, you will be invited to log in.

.. image:: /user/tutorial/images/log-in.png
   :alt: Log in
   :width: 300
   :align: right


The developers of your site are responsible for creating and providing the login credentials so
consult them if you are unsure.
